@@ -228,9 +228,12 @@ def process_member_sample(samples, sample_path, verbose=False) -> dict:
             overall_status[class_o.name()] = 0
 
     # calculate percentage of preservation
-    overall_status["percentage-preserved"] = (
-        overall_status["preserved-count"] / overall_status["sample-count"]
-    ) * 100
+    if overall_status["sample-count"] > 0:
+        overall_status["percentage-preserved"] = (
+            overall_status["preserved-count"] / overall_status["sample-count"]
+        ) * 100
+    else:
+        overall_status["percentage-preserved"] = 0
 
     # add the counters
     overall_status["preserved-in-one-archive"] = one_archive
